from google.protobuf import timestamp_pb2 as _timestamp_pb2
from flyteidl.core import identifier_pb2 as _identifier_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Granularity(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    UNSET: _ClassVar[Granularity]
    MINUTE: _ClassVar[Granularity]
    HOUR: _ClassVar[Granularity]
    DAY: _ClassVar[Granularity]
    MONTH: _ClassVar[Granularity]

class Operator(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    MINUS: _ClassVar[Operator]
    PLUS: _ClassVar[Operator]
UNSET: Granularity
MINUTE: Granularity
HOUR: Granularity
DAY: Granularity
MONTH: Granularity
MINUS: Operator
PLUS: Operator

class ArtifactKey(_message.Message):
    __slots__ = ["project", "domain", "name", "org"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ORG_FIELD_NUMBER: _ClassVar[int]
    project: str
    domain: str
    name: str
    org: str
    def __init__(self, project: _Optional[str] = ..., domain: _Optional[str] = ..., name: _Optional[str] = ..., org: _Optional[str] = ...) -> None: ...

class ArtifactBindingData(_message.Message):
    __slots__ = ["partition_key", "bind_to_time_partition", "time_transform"]
    PARTITION_KEY_FIELD_NUMBER: _ClassVar[int]
    BIND_TO_TIME_PARTITION_FIELD_NUMBER: _ClassVar[int]
    TIME_TRANSFORM_FIELD_NUMBER: _ClassVar[int]
    partition_key: str
    bind_to_time_partition: bool
    time_transform: TimeTransform
    def __init__(self, partition_key: _Optional[str] = ..., bind_to_time_partition: bool = ..., time_transform: _Optional[_Union[TimeTransform, _Mapping]] = ...) -> None: ...

class TimeTransform(_message.Message):
    __slots__ = ["transform", "op"]
    TRANSFORM_FIELD_NUMBER: _ClassVar[int]
    OP_FIELD_NUMBER: _ClassVar[int]
    transform: str
    op: Operator
    def __init__(self, transform: _Optional[str] = ..., op: _Optional[_Union[Operator, str]] = ...) -> None: ...

class InputBindingData(_message.Message):
    __slots__ = ["var"]
    VAR_FIELD_NUMBER: _ClassVar[int]
    var: str
    def __init__(self, var: _Optional[str] = ...) -> None: ...

class RuntimeBinding(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class LabelValue(_message.Message):
    __slots__ = ["static_value", "time_value", "triggered_binding", "input_binding", "runtime_binding"]
    STATIC_VALUE_FIELD_NUMBER: _ClassVar[int]
    TIME_VALUE_FIELD_NUMBER: _ClassVar[int]
    TRIGGERED_BINDING_FIELD_NUMBER: _ClassVar[int]
    INPUT_BINDING_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_BINDING_FIELD_NUMBER: _ClassVar[int]
    static_value: str
    time_value: _timestamp_pb2.Timestamp
    triggered_binding: ArtifactBindingData
    input_binding: InputBindingData
    runtime_binding: RuntimeBinding
    def __init__(self, static_value: _Optional[str] = ..., time_value: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., triggered_binding: _Optional[_Union[ArtifactBindingData, _Mapping]] = ..., input_binding: _Optional[_Union[InputBindingData, _Mapping]] = ..., runtime_binding: _Optional[_Union[RuntimeBinding, _Mapping]] = ...) -> None: ...

class Partitions(_message.Message):
    __slots__ = ["value"]
    class ValueEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: LabelValue
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[LabelValue, _Mapping]] = ...) -> None: ...
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: _containers.MessageMap[str, LabelValue]
    def __init__(self, value: _Optional[_Mapping[str, LabelValue]] = ...) -> None: ...

class TimePartition(_message.Message):
    __slots__ = ["value", "granularity"]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    GRANULARITY_FIELD_NUMBER: _ClassVar[int]
    value: LabelValue
    granularity: Granularity
    def __init__(self, value: _Optional[_Union[LabelValue, _Mapping]] = ..., granularity: _Optional[_Union[Granularity, str]] = ...) -> None: ...

class ArtifactID(_message.Message):
    __slots__ = ["artifact_key", "version", "partitions", "time_partition"]
    ARTIFACT_KEY_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    PARTITIONS_FIELD_NUMBER: _ClassVar[int]
    TIME_PARTITION_FIELD_NUMBER: _ClassVar[int]
    artifact_key: ArtifactKey
    version: str
    partitions: Partitions
    time_partition: TimePartition
    def __init__(self, artifact_key: _Optional[_Union[ArtifactKey, _Mapping]] = ..., version: _Optional[str] = ..., partitions: _Optional[_Union[Partitions, _Mapping]] = ..., time_partition: _Optional[_Union[TimePartition, _Mapping]] = ...) -> None: ...

class ArtifactTag(_message.Message):
    __slots__ = ["artifact_key", "value"]
    ARTIFACT_KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    artifact_key: ArtifactKey
    value: LabelValue
    def __init__(self, artifact_key: _Optional[_Union[ArtifactKey, _Mapping]] = ..., value: _Optional[_Union[LabelValue, _Mapping]] = ...) -> None: ...

class ArtifactQuery(_message.Message):
    __slots__ = ["artifact_id", "artifact_tag", "uri", "binding"]
    ARTIFACT_ID_FIELD_NUMBER: _ClassVar[int]
    ARTIFACT_TAG_FIELD_NUMBER: _ClassVar[int]
    URI_FIELD_NUMBER: _ClassVar[int]
    BINDING_FIELD_NUMBER: _ClassVar[int]
    artifact_id: ArtifactID
    artifact_tag: ArtifactTag
    uri: str
    binding: ArtifactBindingData
    def __init__(self, artifact_id: _Optional[_Union[ArtifactID, _Mapping]] = ..., artifact_tag: _Optional[_Union[ArtifactTag, _Mapping]] = ..., uri: _Optional[str] = ..., binding: _Optional[_Union[ArtifactBindingData, _Mapping]] = ...) -> None: ...



from flyteidl.core import execution_pb2 as _execution_pb2
from flyteidl.core import identifier_pb2 as _identifier_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Waitable(_message.Message):
    __slots__ = ["wf_exec_id", "phase", "workflow_id"]
    WF_EXEC_ID_FIELD_NUMBER: _ClassVar[int]
    PHASE_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    wf_exec_id: _identifier_pb2.WorkflowExecutionIdentifier
    phase: _execution_pb2.WorkflowExecution.Phase
    workflow_id: str
    def __init__(self, wf_exec_id: _Optional[_Union[_identifier_pb2.WorkflowExecutionIdentifier, _Mapping]] = ..., phase: _Optional[_Union[_execution_pb2.WorkflowExecution.Phase, str]] = ..., workflow_id: _Optional[str] = ...) -> None: ...



from flyteidl.core import tasks_pb2 as _tasks_pb2
from flyteidl.plugins.kubeflow import common_pb2 as _common_pb2
from flyteidl.plugins import common_pb2 as _common_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ElasticConfig(_message.Message):
    __slots__ = ["rdzv_backend", "min_replicas", "max_replicas", "nproc_per_node", "max_restarts"]
    RDZV_BACKEND_FIELD_NUMBER: _ClassVar[int]
    MIN_REPLICAS_FIELD_NUMBER: _ClassVar[int]
    MAX_REPLICAS_FIELD_NUMBER: _ClassVar[int]
    NPROC_PER_NODE_FIELD_NUMBER: _ClassVar[int]
    MAX_RESTARTS_FIELD_NUMBER: _ClassVar[int]
    rdzv_backend: str
    min_replicas: int
    max_replicas: int
    nproc_per_node: int
    max_restarts: int
    def __init__(self, rdzv_backend: _Optional[str] = ..., min_replicas: _Optional[int] = ..., max_replicas: _Optional[int] = ..., nproc_per_node: _Optional[int] = ..., max_restarts: _Optional[int] = ...) -> None: ...

class DistributedPyTorchTrainingTask(_message.Message):
    __slots__ = ["worker_replicas", "master_replicas", "run_policy", "elastic_config"]
    WORKER_REPLICAS_FIELD_NUMBER: _ClassVar[int]
    MASTER_REPLICAS_FIELD_NUMBER: _ClassVar[int]
    RUN_POLICY_FIELD_NUMBER: _ClassVar[int]
    ELASTIC_CONFIG_FIELD_NUMBER: _ClassVar[int]
    worker_replicas: DistributedPyTorchTrainingReplicaSpec
    master_replicas: DistributedPyTorchTrainingReplicaSpec
    run_policy: _common_pb2.RunPolicy
    elastic_config: ElasticConfig
    def __init__(self, worker_replicas: _Optional[_Union[DistributedPyTorchTrainingReplicaSpec, _Mapping]] = ..., master_replicas: _Optional[_Union[DistributedPyTorchTrainingReplicaSpec, _Mapping]] = ..., run_policy: _Optional[_Union[_common_pb2.RunPolicy, _Mapping]] = ..., elastic_config: _Optional[_Union[ElasticConfig, _Mapping]] = ...) -> None: ...

class DistributedPyTorchTrainingReplicaSpec(_message.Message):
    __slots__ = ["replicas", "image", "resources", "restart_policy", "common"]
    REPLICAS_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    RESOURCES_FIELD_NUMBER: _ClassVar[int]
    RESTART_POLICY_FIELD_NUMBER: _ClassVar[int]
    COMMON_FIELD_NUMBER: _ClassVar[int]
    replicas: int
    image: str
    resources: _tasks_pb2.Resources
    restart_policy: _common_pb2_1.RestartPolicy
    common: _common_pb2_1.CommonReplicaSpec
    def __init__(self, replicas: _Optional[int] = ..., image: _Optional[str] = ..., resources: _Optional[_Union[_tasks_pb2.Resources, _Mapping]] = ..., restart_policy: _Optional[_Union[_common_pb2_1.RestartPolicy, str]] = ..., common: _Optional[_Union[_common_pb2_1.CommonReplicaSpec, _Mapping]] = ...) -> None: ...



from flyteidl.core import literals_pb2 as _literals_pb2
from flyteidl.core import types_pb2 as _types_pb2
from flyteidl.core import identifier_pb2 as _identifier_pb2
from flyteidl.core import interface_pb2 as _interface_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class KeyMapMetadata(_message.Message):
    __slots__ = ["values"]
    class ValuesEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    VALUES_FIELD_NUMBER: _ClassVar[int]
    values: _containers.ScalarMap[str, str]
    def __init__(self, values: _Optional[_Mapping[str, str]] = ...) -> None: ...

class Metadata(_message.Message):
    __slots__ = ["source_identifier", "key_map", "created_at", "last_updated_at"]
    SOURCE_IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    KEY_MAP_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    LAST_UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    source_identifier: _identifier_pb2.Identifier
    key_map: KeyMapMetadata
    created_at: _timestamp_pb2.Timestamp
    last_updated_at: _timestamp_pb2.Timestamp
    def __init__(self, source_identifier: _Optional[_Union[_identifier_pb2.Identifier, _Mapping]] = ..., key_map: _Optional[_Union[KeyMapMetadata, _Mapping]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., last_updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class CachedOutput(_message.Message):
    __slots__ = ["output_literals", "output_uri", "metadata"]
    OUTPUT_LITERALS_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_URI_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    output_literals: _literals_pb2.LiteralMap
    output_uri: str
    metadata: Metadata
    def __init__(self, output_literals: _Optional[_Union[_literals_pb2.LiteralMap, _Mapping]] = ..., output_uri: _Optional[str] = ..., metadata: _Optional[_Union[Metadata, _Mapping]] = ...) -> None: ...

class GetCacheRequest(_message.Message):
    __slots__ = ["key"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    key: str
    def __init__(self, key: _Optional[str] = ...) -> None: ...

class GetCacheResponse(_message.Message):
    __slots__ = ["output"]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    output: CachedOutput
    def __init__(self, output: _Optional[_Union[CachedOutput, _Mapping]] = ...) -> None: ...

class PutCacheRequest(_message.Message):
    __slots__ = ["key", "output", "overwrite"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    OVERWRITE_FIELD_NUMBER: _ClassVar[int]
    key: str
    output: CachedOutput
    overwrite: bool
    def __init__(self, key: _Optional[str] = ..., output: _Optional[_Union[CachedOutput, _Mapping]] = ..., overwrite: bool = ...) -> None: ...

class PutCacheResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteCacheRequest(_message.Message):
    __slots__ = ["key"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    key: str
    def __init__(self, key: _Optional[str] = ...) -> None: ...

class DeleteCacheResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class Reservation(_message.Message):
    __slots__ = ["key", "owner_id", "heartbeat_interval", "expires_at"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    OWNER_ID_FIELD_NUMBER: _ClassVar[int]
    HEARTBEAT_INTERVAL_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    key: str
    owner_id: str
    heartbeat_interval: _duration_pb2.Duration
    expires_at: _timestamp_pb2.Timestamp
    def __init__(self, key: _Optional[str] = ..., owner_id: _Optional[str] = ..., heartbeat_interval: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., expires_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class GetOrExtendReservationRequest(_message.Message):
    __slots__ = ["key", "owner_id", "heartbeat_interval"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    OWNER_ID_FIELD_NUMBER: _ClassVar[int]
    HEARTBEAT_INTERVAL_FIELD_NUMBER: _ClassVar[int]
    key: str
    owner_id: str
    heartbeat_interval: _duration_pb2.Duration
    def __init__(self, key: _Optional[str] = ..., owner_id: _Optional[str] = ..., heartbeat_interval: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class GetOrExtendReservationResponse(_message.Message):
    __slots__ = ["reservation"]
    RESERVATION_FIELD_NUMBER: _ClassVar[int]
    reservation: Reservation
    def __init__(self, reservation: _Optional[_Union[Reservation, _Mapping]] = ...) -> None: ...

class ReleaseReservationRequest(_message.Message):
    __slots__ = ["key", "owner_id"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    OWNER_ID_FIELD_NUMBER: _ClassVar[int]
    key: str
    owner_id: str
    def __init__(self, key: _Optional[str] = ..., owner_id: _Optional[str] = ...) -> None: ...

class ReleaseReservationResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from flyteidl.core import tasks_pb2 as _tasks_pb2
from flyteidl.plugins.kubeflow import common_pb2 as _common_pb2
from flyteidl.plugins import common_pb2 as _common_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DistributedMPITrainingTask(_message.Message):
    __slots__ = ["worker_replicas", "launcher_replicas", "run_policy", "slots"]
    WORKER_REPLICAS_FIELD_NUMBER: _ClassVar[int]
    LAUNCHER_REPLICAS_FIELD_NUMBER: _ClassVar[int]
    RUN_POLICY_FIELD_NUMBER: _ClassVar[int]
    SLOTS_FIELD_NUMBER: _ClassVar[int]
    worker_replicas: DistributedMPITrainingReplicaSpec
    launcher_replicas: DistributedMPITrainingReplicaSpec
    run_policy: _common_pb2.RunPolicy
    slots: int
    def __init__(self, worker_replicas: _Optional[_Union[DistributedMPITrainingReplicaSpec, _Mapping]] = ..., launcher_replicas: _Optional[_Union[DistributedMPITrainingReplicaSpec, _Mapping]] = ..., run_policy: _Optional[_Union[_common_pb2.RunPolicy, _Mapping]] = ..., slots: _Optional[int] = ...) -> None: ...

class DistributedMPITrainingReplicaSpec(_message.Message):
    __slots__ = ["replicas", "image", "resources", "restart_policy", "command", "common"]
    REPLICAS_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    RESOURCES_FIELD_NUMBER: _ClassVar[int]
    RESTART_POLICY_FIELD_NUMBER: _ClassVar[int]
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    COMMON_FIELD_NUMBER: _ClassVar[int]
    replicas: int
    image: str
    resources: _tasks_pb2.Resources
    restart_policy: _common_pb2_1.RestartPolicy
    command: _containers.RepeatedScalarFieldContainer[str]
    common: _common_pb2_1.CommonReplicaSpec
    def __init__(self, replicas: _Optional[int] = ..., image: _Optional[str] = ..., resources: _Optional[_Union[_tasks_pb2.Resources, _Mapping]] = ..., restart_policy: _Optional[_Union[_common_pb2_1.RestartPolicy, str]] = ..., command: _Optional[_Iterable[str]] = ..., common: _Optional[_Union[_common_pb2_1.CommonReplicaSpec, _Mapping]] = ...) -> None: ...
